@@ -1,6 +1,12 @@
 function gradio(config, fn, target) {
   target = $(target);
   target.html(`
+    <div class="share invisible">
+      Live at <a class="share-link" target="_blank"></a>.
+      <button class="share-copy">Copy Link</button>
+    </div>
+    <h1 class="title"></h1>
+    <p class="description"></p>
     <div class="panels">
       <div class="panel input_panel">
         <div class="input_interfaces">
@@ -12,19 +18,26 @@ function gradio(config, fn, target) {
       </div>
       <div class="panel output_panel">
         <div class="loading invisible">
-          <img class="loading_in_progress" src="static/img/logo_loading.gif">
-          <img class="loading_failed" src="static/img/logo_error.png">
+          <img class="loading_in_progress" src="/static/img/logo_loading.gif">
+          <img class="loading_failed" src="/static/img/logo_error.png">
         </div>
         <div class="output_interfaces">
         </div>
         <div class="panel_buttons">
           <input class="screenshot panel_button" type="button" value="SCREENSHOT"/>
           <div class="screenshot_logo">
-            <img src="static/img/logo_inline.png">
+            <img src="/static/img/logo_inline.png">
           </div>
           <input class="flag panel_button" type="button" value="FLAG"/>
+        </div>
       </div>
-    </div>`);
+    </div>
+    <div class="examples invisible">
+      <h3>Examples <small>(click to load)</small></h3>
+      <table>
+      </table>
+    </div>
+`);
     let io_master = Object.create(io_master_template);
     io_master.fn = fn
     io_master.target = target;
@@ -65,6 +78,22 @@ function gradio(config, fn, target) {
       interface.id = id;
       id_to_interface_map[id] = interface;
     }
+    if (config["title"]) {
+      target.find(".title").text(config["title"]);
+    }
+    if (config["description"]) {
+      target.find(".description").text(config["description"]);
+    }
+    if (config["share_url"]) {
+      let share_url = config["share_url"];
+      target.find(".share").removeClass("invisible");
+      target.find(".share-link").text(share_url).attr("href", share_url);
+      target.find(".share-copy").click(function() {
+        copyToClipboard(share_url);
+        target.find(".share-copy").text("Copied!");
+      })
+    };
+
   
     _id = 0;
     let input_interfaces = [];
@@ -147,6 +176,34 @@ function gradio(config, fn, target) {
       target.find(".screenshot").css("visibility", "visible");
       target.find(".flag").css("visibility", "visible")
     }
+    if (config["examples"]) {
+      target.find(".examples").removeClass("invisible");
+      let html = "<thead>"
+      for (let i = 0; i < config["input_interfaces"].length; i++) {
+        label = config["input_interfaces"][i][1]["label"];
+        html += "<th>" + label + "</th>";
+      }
+      html += "</thead>";
+      html += "<tbody>";
+      for (let [i, example] of config["examples"].entries()) {
+        html += "<tr row="+i+">";
+        for (let [j, col] of example.entries()) {
+          if (input_interfaces[j].load_example_preview) {
+            col = input_interfaces[j].load_example_preview(col);
+          }
+          html += "<td>" + col + "</td>";
+        }
+        html += "</tr>";
+      }
+      html += "</tbody>";
+      target.find(".examples table").html(html);
+      target.find(".examples tr").click(function() {
+        let example_id = parseInt($(this).attr("row"));
+        for (let [i, value] of config["examples"][example_id].entries()) {
+          input_interfaces[i].load_example(value);
+        }
+      })
+    };
 
     target.find(".screenshot").click(function() {
       $(".screenshot").hide();
